@@ -584,10 +584,6 @@ activate (GtkApplication* app,
 {
   GtkWidget *headerbar;
   GtkWidget *label;
-  GdkGeometry size_hints = {
-    800, 600, 0, 0, 800, 600, 0, 0, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST  
-  };
-
   GtkWidget *vbox;
   ClutterColor stage_color = {0x00,0x00,0x00,0xff};
 
@@ -601,14 +597,8 @@ activate (GtkApplication* app,
   gtk_widget_show (headerbar);
 
   window = gtk_application_window_new (app);
-
   gtk_window_set_titlebar (GTK_WINDOW (window), headerbar);
 
-  gtk_window_set_geometry_hints (GTK_WINDOW (window),
-                    window,
-                    &size_hints,
-                    GDK_HINT_MIN_SIZE);
-
   g_action_map_add_action_entries (G_ACTION_MAP (app), app_entries, G_N_ELEMENTS (app_entries), app);
 
   builder = gtk_builder_new ();
@@ -678,6 +668,7 @@ activate (GtkApplication* app,
   clutter_actor_set_size (CLUTTER_ACTOR (stage),
                           properties->tilesize * BOARDWIDTH,
                           properties->tilesize * BOARDHEIGHT);
+  gtk_widget_set_size_request (clutter_widget, DEFAULT_WIDTH, DEFAULT_HEIGHT);
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
