@@ -34,32 +34,6 @@ extern GdkPixbuf *boni_pixmaps[];
 extern GnibblesBoard *board;
 extern ClutterActor *stage;
 
-static void animate_warp1 (ClutterAnimation *animation, ClutterActor *actor);
-static void animate_warp2 (ClutterAnimation *animation, ClutterActor *actor);
-
-static void
-animate_warp1 (ClutterAnimation *animation, ClutterActor *actor)
-{
-  g_signal_connect_after (
-    clutter_actor_animate (actor, CLUTTER_LINEAR, 1100,
-                           "opacity", 0x96,
-                           NULL),
-     "completed", G_CALLBACK (animate_warp2), actor);
-
-}
-
-static void
-animate_warp2 (ClutterAnimation *animation, ClutterActor *actor)
-{
-  g_signal_connect_after (
-    clutter_actor_animate (actor, CLUTTER_LINEAR, 1100,
-                           "opacity", 0xff,
-                           NULL),
-    "completed", G_CALLBACK (animate_warp1), actor);
-
-}
-
-
 GnibblesWarp *
 gnibbles_warp_new (gint t_x, gint t_y, gint t_wx, gint t_wy)
 {
@@ -90,14 +64,15 @@ gnibbles_warp_draw (GnibblesWarp *warp)
   clutter_actor_set_position (CLUTTER_ACTOR (warp->actor),
                               properties->tilesize * warp->x,
                               properties->tilesize * warp->y);
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), warp->actor);
+  clutter_actor_add_child (stage, warp->actor);
   clutter_actor_set_opacity (warp->actor, 0);
   clutter_actor_set_scale (warp->actor, 2.0, 2.0);
-  //g_signal_connect_after (
-    clutter_actor_animate (warp->actor, CLUTTER_EASE_OUT_CIRC, 410,
-                          "scale-x", 1.0, "scale-y", 1.0,
-                          "fixed::scale-gravity", CLUTTER_GRAVITY_CENTER,
-                          "opacity", 0xff,
-                          NULL);
-   //"completed", G_CALLBACK (animate_warp1), warp->actor);
+
+  clutter_actor_save_easing_state(warp->actor);
+  clutter_actor_set_easing_mode (warp->actor, CLUTTER_EASE_OUT_CIRC);
+  clutter_actor_set_easing_duration (warp->actor, 410);
+  clutter_actor_set_scale (warp->actor, 1.0, 1.0);
+  clutter_actor_set_pivot_point (warp->actor,.5,.5); 
+  clutter_actor_set_opacity (warp->actor, 0xff);
+  clutter_actor_restore_easing_state(warp->actor);
 }
